$.jqplot.shadowRenderer

The default jqPlot shadow renderer, rendering shadows behind shapes.

Summary

$.jqplot.shadowRenderer | The default jqPlot shadow renderer, rendering shadows behind shapes.
Properties |
angle | Angle of the shadow in degrees.
offset | Pixel offset at the given shadow angle of each shadow stroke from the last stroke.
alpha | alpha transparency of shadow stroke.
lineWidth | width of the shadow line stroke.
lineJoin | How line segments of the shadow are joined.
lineCap | how ends of the shadow line are rendered.
fill | whether to fill the shape.
depth | how many times the shadow is stroked.
isarc | whether the shadow is an arc or not.
draw | draws an transparent black (i.e.

### Properties

### angle

> this.angle = 45

Angle of the shadow in degrees. Measured counter-clockwise from the x axis.

### offset

> this.offset = 1

Pixel offset at the given shadow angle of each shadow stroke from the last stroke.

### alpha

> this.alpha = 0.07

alpha transparency of shadow stroke.

### lineWidth

> this.lineWidth = 1.5

width of the shadow line stroke.

### lineJoin

> this.lineJoin = 'miter'

How line segments of the shadow are joined.

### lineCap

> this.lineCap = 'round'

how ends of the shadow line are rendered.

### fill

> this.fill = false

whether to fill the shape.

### depth

> this.depth = 3

how many times the shadow is stroked. Each stroke will be offset by offset at angle degrees.

### isarc

> this.isarc = false

whether the shadow is an arc or not.

### draw

> $.jqplot.ShadowRenderer.prototype.draw = function( | ctx,
> | points,
> | options | )

draws an transparent black (i.e. gray) shadow.

ctx | canvas drawing context
points | array of points or [x, y, radius, start angle (rad), end angle (rad)]

> this.angle = 45

Angle of the shadow in degrees.

> this.offset = 1

Pixel offset at the given shadow angle of each shadow stroke from the last stroke.

> this.alpha = 0.07

alpha transparency of shadow stroke.

> this.lineWidth = 1.5

width of the shadow line stroke.

> this.lineJoin = 'miter'

How line segments of the shadow are joined.

> this.lineCap = 'round'

how ends of the shadow line are rendered.

> this.fill = false

whether to fill the shape.

> this.depth = 3

how many times the shadow is stroked.

> this.isarc = false

whether the shadow is an arc or not.

> $.jqplot.ShadowRenderer.prototype.draw = function( | ctx,
> | points,
> | options | )

draws an transparent black (i.e.
Close